@@ -1,15 +1,16 @@
-/*
- * Truncate the name of the given object if it is greater than the postgres default max (63 characters).
- * Also appends given suffix and schema if given and truncates the name so that the entire suffix will fit.
- * Returns original name with schema given if it doesn't require truncation
- */
 CREATE FUNCTION check_name_length (p_object_name text, p_suffix text DEFAULT NULL, p_table_partition boolean DEFAULT FALSE) RETURNS text
-    LANGUAGE plpgsql IMMUTABLE
+    LANGUAGE plpgsql IMMUTABLE SECURITY DEFINER
     AS $$
 DECLARE
     v_new_length    int;
     v_new_name      text;
 BEGIN
+/*
+ * Truncate the name of the given object if it is greater than the postgres default max (63 characters).
+ * Also appends given suffix and schema if given and truncates the name so that the entire suffix will fit.
+ * Returns original name (with suffix if given) if it doesn't require truncation
+ * Given security definer since it's called by the trigger functions
+ */
 
 IF p_table_partition IS TRUE AND (p_suffix IS NULL) THEN
     RAISE EXCEPTION 'Table partition name requires a suffix value';
@@ -36,4 +37,3 @@ RETURN v_new_name;
 END
 $$;
 
-
