@@ -42,6 +42,7 @@ v_native_sub_control            text;
 v_notnull                       boolean;
 v_new_search_path               text := '@extschema@,pg_temp';
 v_old_search_path               text;
+v_parent_owner                  text;
 v_parent_partition_id           bigint;
 v_parent_partition_timestamp    timestamptz;
 v_parent_schema                 text;
@@ -162,6 +163,17 @@ IF p_type = 'native' THEN
         v_template_schema := '@extschema@';
         v_template_tablename := @extschema@.check_name_length('template_'||v_parent_schema||'_'||v_parent_tablename);
         EXECUTE format('CREATE TABLE IF NOT EXISTS %I.%I (LIKE %I.%I)', '@extschema@', v_template_tablename, v_parent_schema, v_parent_tablename);
+
+        SELECT pg_get_userbyid(c.relowner) INTO v_parent_owner 
+        FROM pg_catalog.pg_class c
+        JOIN pg_catalog.pg_namespace n ON c.relnamespace = n.oid
+        WHERE n.nspname = v_parent_schema::name 
+        AND c.relname = v_parent_tablename::name;
+
+        EXECUTE format('ALTER TABLE %I.%I OWNER TO %I'
+                , '@extschema@' 
+                , v_template_tablename 
+                , v_parent_owner);
     ELSE
         SELECT n.nspname, c.relname INTO v_template_schema, v_template_tablename
         FROM pg_catalog.pg_class c
