@@ -1,11 +1,3 @@
-/*
- * Function to manage pre-creation of the next partitions in a set.
- * Also manages dropping old partitions if the retention option is set.
- * If p_parent_table is passed, will only run run_maintenance() on that one table (no matter what the configuration table may have set for it)
- * Otherwise, will run on all tables in the config table with p_run_maintenance() set to true.
- * For large partition sets, running analyze can cause maintenance to take longer than expected. Can set p_analyze to false to avoid a forced analyze run.
- * Be aware that constraint exclusion may not work properly until an analyze on the partition set is run. 
- */
 CREATE FUNCTION run_maintenance(p_parent_table text DEFAULT NULL, p_analyze boolean DEFAULT true, p_jobmon boolean DEFAULT true, p_debug boolean DEFAULT false) RETURNS void 
     LANGUAGE plpgsql SECURITY DEFINER
     AS $$
@@ -17,6 +9,7 @@ ex_hint                         text;
 ex_message                      text;
 v_adv_lock                      boolean;
 v_check_subpart                 int;
+v_control_type                  text;
 v_create_count                  int := 0;
 v_current_partition             text;
 v_current_partition_id          bigint;
@@ -60,6 +53,14 @@ v_tablename                     text;
 v_tables_list_sql               text;
 
 BEGIN
+/*
+ * Function to manage pre-creation of the next partitions in a set.
+ * Also manages dropping old partitions if the retention option is set.
+ * If p_parent_table is passed, will only run run_maintenance() on that one table (no matter what the configuration table may have set for it)
+ * Otherwise, will run on all tables in the config table with p_automatic_maintenance() set to true.
+ * For large partition sets, running analyze can cause maintenance to take longer than expected. Can set p_analyze to false to avoid a forced analyze run.
+ * Be aware that constraint exclusion may not work properly until an analyze on the partition set is run. 
+ */
 
 v_adv_lock := pg_try_advisory_xact_lock(hashtext('pg_partman run_maintenance'));
 IF v_adv_lock = 'false' THEN
@@ -92,11 +93,12 @@ v_tables_list_sql := 'SELECT parent_table
                 , sub_partition_set_full
                 , epoch
                 , infinite_time_partitions
+                , retention
             FROM @extschema@.part_config
-            WHERE sub_partition_set_full = false';
+            WHERE undo_in_progress = false';
 
 IF p_parent_table IS NULL THEN
-    v_tables_list_sql := v_tables_list_sql || ' AND use_run_maintenance = true';
+    v_tables_list_sql := v_tables_list_sql || ' AND automatic_maintenance = ''on''';
 ELSE
     v_tables_list_sql := v_tables_list_sql || format(' AND parent_table = %L', p_parent_table);
 END IF;
@@ -109,7 +111,6 @@ LOOP
     -- Check for consistent data in part_config_sub table. Was unable to get this working properly as either a constraint or trigger. 
     -- Would either delay raising an error until the next write (which I cannot predict) or disallow future edits to update a sub-partition set's configuration.
     -- This way at least provides a consistent way to check that I know will run. If anyone can get a working constraint/trigger, please help!
-    -- Don't have to worry about this in the serial trigger maintenance since subpartitioning requires run_maintenance().
     SELECT sub_parent INTO v_sub_parent FROM @extschema@.part_config_sub WHERE sub_parent = v_row.parent_table;
     IF v_sub_parent IS NOT NULL THEN
         SELECT count(*) INTO v_check_subpart FROM @extschema@.check_subpart_sameconfig(v_row.parent_table);
@@ -120,11 +121,14 @@ LOOP
         END IF;
     END IF;
 
-    SELECT schemaname, tablename 
+    SELECT n.nspname, c.relname
     INTO v_parent_schema, v_parent_tablename 
-    FROM pg_catalog.pg_tables 
-    WHERE schemaname = split_part(v_row.parent_table, '.', 1)::name
-    AND tablename = split_part(v_row.parent_table, '.', 2)::name;
+    FROM pg_catalog.pg_class c
+    JOIN pg_catalog.pg_namespace n ON c.relnamespace = n.oid
+    WHERE n.nspname = split_part(v_row.parent_table, '.', 1)::name
+    AND c.relname = split_part(v_row.parent_table, '.', 2)::name;
+
+    SELECT general_type INTO v_control_type FROM @extschema@.check_control_type(v_parent_schema, v_parent_tablename, v_row.control);
 
     v_partition_expression := CASE
         WHEN v_row.epoch = 'seconds' THEN format('to_timestamp(%I)', v_row.control)
@@ -140,26 +144,44 @@ LOOP
         RAISE NOTICE 'run_maint: parent_table: %, v_last_partition: %', v_row.parent_table, v_last_partition;
     END IF;
 
-    IF v_row.partition_type = 'time' OR v_row.partition_type = 'time-custom' THEN
+    IF v_control_type = 'time' OR (v_control_type = 'id' AND v_row.epoch <> 'none') THEN
+
+        -- Run retention if needed
+        IF v_row.retention IS NOT NULL THEN
+            v_drop_count := v_drop_count + @extschema@.drop_partition_time(v_row.parent_table);   
+            IF v_drop_count > 0 AND v_row.partition_type <> 'native' THEN
+                PERFORM @extschema@.create_function_time(v_row.parent_table, v_job_id);
+            END IF;
+        END IF;
+
+        IF v_row.sub_partition_set_full THEN CONTINUE; END IF;
 
         SELECT child_start_time INTO v_last_partition_timestamp 
             FROM @extschema@.show_partition_info(v_parent_schema||'.'||v_last_partition, v_row.partition_interval, v_row.parent_table);
-
         -- Loop through child tables starting from highest to get current max value in partition set
         -- Avoids doing a scan on entire partition set and/or getting any values accidentally in parent.
-        FOR v_row_max_time IN
-            SELECT partition_schemaname, partition_tablename FROM @extschema@.show_partitions(v_row.parent_table, 'DESC')
-        LOOP
-            EXECUTE format('SELECT max(%s)::text FROM %I.%I'
-                                , v_partition_expression
-                                , v_row_max_time.partition_schemaname
-                                , v_row_max_time.partition_tablename
-                            ) INTO v_current_partition_timestamp;
-            IF v_current_partition_timestamp IS NOT NULL THEN
-                SELECT suffix_timestamp INTO v_current_partition_timestamp FROM @extschema@.show_partition_name(v_row.parent_table, v_current_partition_timestamp::text);
-                EXIT;
-            END IF;
-        END LOOP;
+
+        IF v_row.infinite_time_partitions IS TRUE THEN
+            -- Set it to "now" so new partitions continue to be created
+            -- For infinite_time_partitions, don't bother getting the max value in the partitions
+            v_current_partition_timestamp = CURRENT_TIMESTAMP;
+        ELSE 
+            FOR v_row_max_time IN
+                SELECT partition_schemaname, partition_tablename FROM @extschema@.show_partitions(v_row.parent_table, 'DESC')
+            LOOP
+                EXECUTE format('SELECT max(%s)::text FROM %I.%I'
+                                    , v_partition_expression
+                                    , v_row_max_time.partition_schemaname
+                                    , v_row_max_time.partition_tablename
+                                ) INTO v_current_partition_timestamp;
+
+                IF v_current_partition_timestamp IS NOT NULL THEN
+                    SELECT suffix_timestamp INTO v_current_partition_timestamp FROM @extschema@.show_partition_name(v_row.parent_table, v_current_partition_timestamp::text);
+                    EXIT;
+                END IF;
+            END LOOP;
+        END IF; -- end infinite time check
+
         -- Check for values in the parent table. If they are there and greater than all child values, use that instead
         -- This allows maintenance to continue working properly if there is a large gap in data insertion. Data will remain in parent, but new tables will be created
         EXECUTE format('SELECT max(%s) FROM ONLY %I.%I', v_partition_expression, v_parent_schema, v_parent_tablename) INTO v_max_time_parent;
@@ -169,14 +191,11 @@ LOOP
         IF v_max_time_parent > v_current_partition_timestamp THEN
             SELECT suffix_timestamp INTO v_current_partition_timestamp FROM @extschema@.show_partition_name(v_row.parent_table, v_max_time_parent::text);
         END IF;
-        IF v_current_partition_timestamp IS NULL THEN -- Partition set is completely empty
-            IF v_row.infinite_time_partitions IS TRUE THEN
-                -- Set it to now so new partitions continue to be created
-                v_current_partition_timestamp = CURRENT_TIMESTAMP;
-            ELSE
-                -- Nothing to do
-                CONTINUE;
-            END IF;
+
+        IF v_current_partition_timestamp IS NULL THEN 
+            -- Partition set is completely empty and infinite time partitions not set
+            -- Nothing to do
+            CONTINUE;
         END IF;
 
         -- If this is a subpartition, determine if the last child table has been made. If so, mark it as full so future maintenance runs can skip it
@@ -220,15 +239,33 @@ LOOP
                 RAISE WARNING 'Attempted partition time interval is outside PostgreSQL''s supported time range. Child partition creation skipped for parent table %', v_row.parent_table;
                 CONTINUE;
             END;
-            v_last_partition_created := @extschema@.create_partition_time(v_row.parent_table, ARRAY[v_next_partition_timestamp], p_analyze); 
+
+            v_last_partition_created := @extschema@.create_partition_time(v_row.parent_table
+                                                        , ARRAY[v_next_partition_timestamp]
+                                                        , p_analyze
+                                                        , p_debug := p_debug); 
             IF v_last_partition_created THEN
                 v_create_count := v_create_count + 1;
-                PERFORM @extschema@.create_function_time(v_row.parent_table, v_job_id);
+                IF v_row.partition_type <> 'native' THEN
+                    PERFORM @extschema@.create_function_time(v_row.parent_table, v_job_id);
+                END IF;
             END IF;
 
             v_premade_count = round(EXTRACT('epoch' FROM age(v_next_partition_timestamp, v_current_partition_timestamp)) / EXTRACT('epoch' FROM v_row.partition_interval::interval));
         END LOOP;
-    ELSIF v_row.partition_type = 'id' THEN
+
+    ELSIF v_control_type = 'id' THEN
+
+        -- Run retention if needed
+        IF v_row.retention IS NOT NULL THEN
+            v_drop_count := v_drop_count + @extschema@.drop_partition_id(v_row.parent_table);   
+            IF v_drop_count > 0 AND v_row.partition_type <> 'native' THEN
+                PERFORM @extschema@.create_function_id(v_row.parent_table, v_job_id);
+            END IF;
+        END IF;
+
+        IF v_row.sub_partition_set_full THEN CONTINUE; END IF;
+
         -- Loop through child tables starting from highest to get current max value in partition set
         -- Avoids doing a scan on entire partition set and/or getting any values accidentally in parent.
         FOR v_row_max_id IN
@@ -282,7 +319,9 @@ LOOP
             v_last_partition_created := @extschema@.create_partition_id(v_row.parent_table, ARRAY[v_next_partition_id], p_analyze);
             IF v_last_partition_created THEN
                 v_create_count := v_create_count + 1;
-                PERFORM @extschema@.create_function_id(v_row.parent_table, v_job_id);
+                IF v_row.partition_type <> 'native' THEN
+                    PERFORM @extschema@.create_function_id(v_row.parent_table, v_job_id);
+                END IF;
             END IF;
             v_premade_count := ((v_next_partition_id - v_current_partition_id) / v_row.partition_interval::bigint);
         END LOOP;
@@ -291,41 +330,6 @@ LOOP
 
 END LOOP; -- end of creation loop
 
--- Manage dropping old partitions if retention option is set
-FOR v_row IN 
-    SELECT parent_table FROM @extschema@.part_config WHERE retention IS NOT NULL AND undo_in_progress = false AND 
-        (partition_type = 'time' OR partition_type = 'time-custom')
-LOOP
-    IF p_parent_table IS NULL THEN
-        v_drop_count := v_drop_count + @extschema@.drop_partition_time(v_row.parent_table);   
-    ELSE -- Only run retention on table given in parameter
-        IF p_parent_table <> v_row.parent_table THEN
-            CONTINUE;
-        ELSE
-            v_drop_count := v_drop_count + @extschema@.drop_partition_time(v_row.parent_table);   
-        END IF;
-    END IF;
-    IF v_drop_count > 0 THEN
-        PERFORM @extschema@.create_function_time(v_row.parent_table, v_job_id);
-    END IF;
-END LOOP; 
-FOR v_row IN 
-    SELECT parent_table FROM @extschema@.part_config WHERE retention IS NOT NULL AND undo_in_progress = false AND partition_type = 'id'
-LOOP
-    IF p_parent_table IS NULL THEN
-        v_drop_count := v_drop_count + @extschema@.drop_partition_id(v_row.parent_table);
-    ELSE -- Only run retention on table given in parameter
-        IF p_parent_table <> v_row.parent_table THEN
-            CONTINUE;
-        ELSE
-            v_drop_count := v_drop_count + @extschema@.drop_partition_id(v_row.parent_table);
-        END IF;
-    END IF;
-    IF v_drop_count > 0 THEN
-        PERFORM @extschema@.create_function_id(v_row.parent_table, v_job_id);
-    END IF;
-END LOOP; 
-
 IF v_jobmon_schema IS NOT NULL THEN
     PERFORM update_step(v_step_id, 'OK', format('Partition maintenance finished. %s partitons made. %s partitions dropped.', v_create_count, v_drop_count));
     IF v_step_overflow_id IS NOT NULL THEN
@@ -360,3 +364,4 @@ HINT: %', ex_message, ex_context, ex_detail, ex_hint;
 END
 $$;
 
+
